package org.dromara.zhishu.mapper;

import org.apache.ibatis.annotations.Mapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.dromara.zhishu.domain.NewUserInfo;
import org.dromara.zhishu.domain.TAudit;
import org.dromara.zhishu.domain.bo.TAuditBo;
import org.dromara.zhishu.domain.vo.TAuditVo;
import org.dromara.common.mybatis.core.mapper.BaseMapperPlus;

import java.util.Collection;

/**
 * 审核Mapper接口
 *
 * @author Lion Li
 * @date 2025-04-01
 */
@Mapper
public interface TAuditMapper extends BaseMapperPlus<TAudit, TAuditVo> {

    NewUserInfo selectUserList(Long id);

    void updateByUser(NewUserInfo newUserInfo);

    void deleteUser(Collection<Long> ids);

    String selectUserName(Long userId);

    int updateStatus(TAuditBo bo);

    Long selectUserId(Long id);

    Integer insertUserRole(Long userId, long l);

    Integer insertAuditLog(TAuditBo bo);

    Integer deleteUserRole(Long userId, long l);

    Page<TAuditVo> selectPageVo(Page<Object> build, TAuditBo bo);

    TAudit selectId(Long id);
}
